@@ -1,19 +1,14 @@
-import click
-
-from globus_cli.parsing import common_options
-
-from globus_cli.commands.bookmark.list import bookmark_list
 from globus_cli.commands.bookmark.create import bookmark_create
 from globus_cli.commands.bookmark.delete import bookmark_delete
+from globus_cli.commands.bookmark.list import bookmark_list
 from globus_cli.commands.bookmark.rename import bookmark_rename
 from globus_cli.commands.bookmark.show import bookmark_show
-from globus_cli.commands.bookmark.locate import bookmark_locate
+from globus_cli.parsing import group
 
 
-@click.group(name='bookmark', help='Manage Endpoint Bookmarks')
-@common_options
+@group("bookmark")
 def bookmark_command():
-    pass
+    """Manage endpoint bookmarks"""
 
 
 bookmark_command.add_command(bookmark_list)
@@ -21,4 +16,3 @@ bookmark_command.add_command(bookmark_create)
 bookmark_command.add_command(bookmark_delete)
 bookmark_command.add_command(bookmark_rename)
 bookmark_command.add_command(bookmark_show)
-bookmark_command.add_command(bookmark_locate)
