@@ -1,17 +1,13 @@
-import click
-
-from globus_cli.parsing import common_options
-
-from globus_cli.commands.endpoint.role.list import role_list
-from globus_cli.commands.endpoint.role.show import role_show
 from globus_cli.commands.endpoint.role.create import role_create
 from globus_cli.commands.endpoint.role.delete import role_delete
+from globus_cli.commands.endpoint.role.list import role_list
+from globus_cli.commands.endpoint.role.show import role_show
+from globus_cli.parsing import group
 
 
-@click.group(name='role', help='Manage endpoint roles')
-@common_options
+@group("role")
 def role_command():
-    pass
+    """Manage endpoint roles"""
 
 
 role_command.add_command(role_list)
