@@ -1,22 +1,19 @@
-import click
-
-from globus_cli.parsing import common_options
-
+from globus_cli.commands.endpoint.server.add import server_add
+from globus_cli.commands.endpoint.server.delete import server_delete
 from globus_cli.commands.endpoint.server.list import server_list
 from globus_cli.commands.endpoint.server.show import server_show
-from globus_cli.commands.endpoint.server.add import server_add
 from globus_cli.commands.endpoint.server.update import server_update
-from globus_cli.commands.endpoint.server.delete import server_delete
+from globus_cli.parsing import group
 
 
-@click.group(name='server', short_help='Manage servers for a Globus Endpoint',
-             help=('Manage the servers which back a Globus Endpoint. '
-                   'This typically refers to a Globus Connect Server endpoint '
-                   'running on multiple servers. Each GridFTP server is '
-                   'registered as a server backing the endpoint.'))
-@common_options
+@group("server", short_help="Manage servers for a Globus endpoint")
 def server_command():
-    pass
+    """
+    Manage the servers which back a Globus endpoint
+
+    This typically refers to a Globus Connect Server endpoint running on multiple
+    servers. Each GridFTP server is registered as a server backing the endpoint.
+    """
 
 
 server_command.add_command(server_list)
